@@ -389,7 +389,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
                             const KMimeType::Ptr ptr = KMimeType::findByUrl(path);
                             if (!ptr->name().isEmpty()) {
                                 hstr += "\r\nContent-Type: ";
-                                hstr += ptr->name().toAscii().constData();
+                                hstr += ptr->name().toLatin1().constData();
                             }
                         } else if (!val.isEmpty()) {
                             fileNotUploads << path.pathOrUrl();
@@ -448,7 +448,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
     }
 
     if (useMultipart)
-        enc_string = QString("--" + m_boundary + "--\r\n").toAscii().constData();
+        enc_string = QString("--" + m_boundary + "--\r\n").toLatin1().constData();
 
     const int old_size = form_data.size();
     form_data.resize( form_data.size() + enc_string.length() );
@@ -824,6 +824,15 @@ void HTMLFormElementImpl::removeFormElement(HTMLGenericFormElementImpl *e)
     int i = formElements.indexOf(e);
     if (i != -1)
         formElements.removeAt(i);
+        
+    if (e->hasPastNames()) {
+        QMutableHashIterator<DOMString, HTMLGenericFormElementImpl*> it(m_pastNamesMap);
+        while (it.hasNext()) {
+            it.next();
+            if (it.value() == e)
+                it.remove();
+        }
+    }
 }
 
 void HTMLFormElementImpl::registerImgElement(HTMLImageElementImpl *e)
@@ -838,12 +847,29 @@ void HTMLFormElementImpl::removeImgElement(HTMLImageElementImpl *e)
         imgElements.removeAt(i);
 }
 
+HTMLGenericFormElementImpl* HTMLFormElementImpl::lookupByPastName(const DOMString& id)
+{
+    return m_pastNamesMap.value(id);
+}
+
+void HTMLFormElementImpl::bindPastName(HTMLGenericFormElementImpl* e)
+{
+    DOMString id = e->getAttribute(ATTR_ID);
+    if (!id.isEmpty())
+        m_pastNamesMap.insert(id, e);
+        
+    DOMString nm = e->getAttribute(ATTR_NAME);
+    if (!nm.isEmpty())
+        m_pastNamesMap.insert(nm, e);
+    e->setHasPastNames();
+}
+
 // -------------------------------------------------------------------------
 
 HTMLGenericFormElementImpl::HTMLGenericFormElementImpl(DocumentImpl *doc, HTMLFormElementImpl *f)
     : HTMLElementImpl(doc)
 {
-    m_disabled = m_readOnly = false;
+    m_disabled = m_readOnly = m_hasPastNames = false;
     m_name = 0;
 
     if (f)
@@ -1003,8 +1029,11 @@ void HTMLGenericFormElementImpl::setDisabled( bool _disabled )
     }
 }
 
-bool HTMLGenericFormElementImpl::isFocusable() const
+bool HTMLGenericFormElementImpl::isFocusableImpl(FocusType ft) const
 {
+    if (hasTabIndex())
+        return HTMLElementImpl::isFocusableImpl(ft);
+
     if (disabled())
 	return false;
 
@@ -1503,6 +1532,9 @@ void HTMLInputElementImpl::parseAttribute(AttributeImpl *attr)
         setHTMLEventListener(EventImpl::CHANGE_EVENT,
             document()->createHTMLEventListener(attr->value().string(), "onchange", this));
         break;
+    case ATTR_PLACEHOLDER:
+        setChanged();
+        break;
     default:
         HTMLGenericFormElementImpl::parseAttribute(attr);
     }
@@ -1515,6 +1547,9 @@ void HTMLInputElementImpl::copyNonAttributeProperties(const ElementImpl* source)
 
     m_value = e->m_value;
     m_checked = e->m_checked;
+    m_defaultChecked = e->m_checked;
+    m_useDefaultChecked = e->m_defaultChecked;
+    m_indeterminate = e->m_indeterminate;
     // ### copy more?
 
     HTMLGenericFormElementImpl::copyNonAttributeProperties(source);
@@ -2009,6 +2044,16 @@ void HTMLInputElementImpl::setSelectionRange(long start, long end)
     static_cast<RenderLineEdit*>(m_render)->setSelectionRange(start, end);
 }
 
+void HTMLInputElementImpl::setPlaceholder(const DOMString& p)
+{
+    setAttribute(ATTR_PLACEHOLDER, p);
+}
+
+DOMString HTMLInputElementImpl::placeholder() const
+{
+    return getAttribute(ATTR_PLACEHOLDER);
+}
+
 // -------------------------------------------------------------------------
 
 HTMLLabelElementImpl::HTMLLabelElementImpl(DocumentImpl *doc)
@@ -2031,6 +2076,16 @@ void HTMLLabelElementImpl::attach()
     HTMLElementImpl::attach();
 }
 
+
+bool HTMLLabelElementImpl::isFocusableImpl(FocusType ft) const
+{
+    if (hasTabIndex())
+        return HTMLGenericFormElementImpl::isFocusableImpl(ft);
+
+    // We want labels to accept focus on click, but not on tabbing.
+    return (ft != FT_Tab);
+}
+
 NodeImpl* HTMLLabelElementImpl::getFormElement()
 {
 	    const DOMString formElementId = getAttribute(ATTR_FOR);
@@ -2901,6 +2956,9 @@ void HTMLTextAreaElementImpl::parseAttribute(AttributeImpl *attr)
         setHTMLEventListener(EventImpl::CHANGE_EVENT,
 	    document()->createHTMLEventListener(attr->value().string(), "onchange", this));
         break;
+    case ATTR_PLACEHOLDER:
+        setChanged();
+        break;
     default:
         HTMLGenericFormElementImpl::parseAttribute(attr);
     }
@@ -3099,6 +3157,16 @@ long HTMLTextAreaElementImpl::textLength()
     return value().length();
 }
 
+void HTMLTextAreaElementImpl::setPlaceholder(const DOMString& p)
+{
+    setAttribute(ATTR_PLACEHOLDER, p);
+}
+
+DOMString HTMLTextAreaElementImpl::placeholder() const
+{
+    return getAttribute(ATTR_PLACEHOLDER);
+}
+
 // -------------------------------------------------------------------------
 
 HTMLIsIndexElementImpl::HTMLIsIndexElementImpl(DocumentImpl *doc, HTMLFormElementImpl *f)
