@@ -933,6 +933,33 @@ void KDirListerTest::testBug211472()
     QVERIFY(QTest::kWaitForSignal(&dirLister, SIGNAL(clear()), 1000));
 }
 
+void KDirListerTest::testRenameCurrentDir() // #294445
+{
+    m_items.clear();
+
+    const QString path = m_tempDir.name() + "newsubdir-1";
+    QVERIFY(QDir().mkdir(path));
+    MyDirLister secondDirLister;
+    connect(&secondDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+
+    secondDirLister.openUrl(KUrl(path));
+    QVERIFY(QTest::kWaitForSignal(&secondDirLister, SIGNAL(completed()), 1000));
+    QVERIFY(secondDirLister.isFinished());
+    QVERIFY(m_items.empty());
+    QCOMPARE(secondDirLister.rootItem().url().toLocalFile(), path);
+
+    const QString newPath = m_tempDir.name() + "newsubdir-2";
+    QVERIFY(QDir().rename(path, newPath));
+    org::kde::KDirNotify::emitFileRenamed(KUrl(path).url(), KUrl(newPath).url());
+    QVERIFY(QTest::kWaitForSignal(&secondDirLister, SIGNAL(redirection(KUrl,KUrl)), 1000));
+
+    // Check that the URL of the root item got updated
+    QCOMPARE(secondDirLister.rootItem().url().toLocalFile(), newPath);
+
+    disconnect(&secondDirLister, 0, this, 0);
+    QDir().remove(newPath);
+}
+
 void KDirListerTest::testRedirection()
 {
     m_items.clear();
